embeddedmany2oneeditor — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

# embeddedmany2oneeditor

class `camelot.view.controls.editors.embeddedmany2oneeditor.` `EmbeddedMany2OneEditor`(admin=None, parent=None, field_name='embedded', size_policy=<PyQt4.QtGui.QSizePolicy object at 0x9f71bfc>, **kwargs)

  Widget for editing a many 2 one relation a a form embedded in another form.

  @todo: properly take care of making the form editable or not, simply enabling or disabling the widget as a whole is not functional, since tabs don’t work in that case

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

Comments
blog comments powered by Disqus